%% Establish Connection to the Power Sensor
VISA = 'USB0::0x2A8D::0x1E01::MY59040003::0::INSTR';
obj1 = instrfind('Type', 'visa-usb', 'RsrcName', VISA, 'Tag', '');

if isempty(obj1)
    obj1 = visa('AGILENT', VISA);
else
    fclose(obj1);
    delete(obj1);
end
obj1.InputBuffer = 1024^2;
obj1.timeout=20;

%% Settings for Trace View
fopen(obj1);
fprintf(obj1, '*RST');

% set sensor to normal mode for trace measurements
fprintf(obj1, 'sens:det:func norm');
fprintf(obj1, 'TRIG1:DEL:AUTO 0');
%fprintf(obj1, 'CALC3:FEED1 "POW:PTAV"');
fprintf(obj1, 'INIT1:CONT 0');
fprintf(obj1, 'TRIG1:SOUR INT1');
fprintf(obj1, 'TRAC1:STAT 1');
fprintf(obj1, 'trac:unit dbm');

%% Start a Measurement and Convert Binary Data to Float
data2 = query(obj1, 'READ1?');
systErr = query(obj1, 'syst:err?');

fprintf(obj1, 'TRAC1:DATA? HRES');
data = binblockread(obj1, 'float');
% remove terminating character not read by binblockread
clrdevice(obj1);
floatdata = cast(data, 'single');
trace = swapbytes(floatdata); %This is the result, which can be plotted
systErr = query(obj1, 'syst:err?');

plot(trace);

%% Close & Delete the Connection
fclose(obj1);
delete(obj1);